@@ -11,14 +11,14 @@ __all__ = [
 class ParsedTools(TypedDict):
     should_use_tool: Optional[bool]
     tool_name: Optional[str]
-    tool_input: Optional[str]
+    tool_input: Optional[dict]
     final_response: Optional[str]
 
 
 scratchpad: Scratchpad[ParsedTools] = Scratchpad[ParsedTools](
     """
 Tool: {tool_name:S}
-Tool Input: {tool_input}
+Tool Input: {tool_input:json}
 Response: {final_response}
 """.strip()
 )
