@@ -26,7 +26,8 @@ Remember that the {{user_type}} ONLY gets to see what you tell me in the format
 
 Tools:
 {% for tool in tools %}
-- {{tool.__name__}}: {{tool.__doc__}}
+{% set tool_signature = tool | input_signature -%}
+- {{tool.__name__}}: {{tool.__doc__}}. This tool{% if tool_signature %} requires a valid json as input that includes these keys: ({{tool_signature}}){% else %} does not require an input{% endif %}.
 {% endfor %}
 
 Think step by step to process the {{user_type}}'s request and use tools to collect required information or take actions. Do NOT make up answers and politely apologize if unable to help even after using the tools.
